
# Slot: subject


gene, product or macromolecular complex mixin that has the function associated with the GO term

URI: [biolink:functional_association_subject](https://w3id.org/biolink/vocab/functional_association_subject)


## Domain and Range

[FunctionalAssociation](FunctionalAssociation.md) &#8594;  <sub>1..1</sub> [MacromolecularMachineMixin](MacromolecularMachineMixin.md)

## Parents

 *  is_a: [subject](subject.md)

## Children

 *  [gene to go term association➞subject](gene_to_go_term_association_subject.md)

## Used by

 * [FunctionalAssociation](FunctionalAssociation.md)
 * [MacromolecularMachineToBiologicalProcessAssociation](MacromolecularMachineToBiologicalProcessAssociation.md)
 * [MacromolecularMachineToCellularComponentAssociation](MacromolecularMachineToCellularComponentAssociation.md)
 * [MacromolecularMachineToMolecularActivityAssociation](MacromolecularMachineToMolecularActivityAssociation.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Examples:** | | Example(value='ZFIN:ZDB-GENE-050417-357', description='twist1b') |

